# frozen_string_literal: true

module Bulkrax
  class RerunImportersController < ApplicationController
    before_action :set_importer, only: [:rerun_failed_entries]

    def rerun_failed_entries
      if @importer.last_run&.failed_records&.positive?
        ScheduleRelationshipsJob.set(wait: 5.minutes).perform_later(importer_id: @importer.id)

        @importer.entries.each do |failed_entry|
          next unless failed_entry.status == 'Failed'

          type = if failed_entry.raw_metadata['model'] == 'CrcDataset'
                   'Work'
                 else
                   failed_entry.raw_metadata['model']
                 end

          "Bulkrax::Import#{type}Job".constantize.send(
            failed_entry.parser.perform_method,
            failed_entry.id,
            @importer.importer_runs.last.id
          )
        end

        @importer.record_status
      elsif @importer.last_run && @importer.parser.total.positive? && @importer.last_run.processed_records.zero?
        Bulkrax::ImporterJob.send(
          @importer.parser.perform_method,
          @importer.id
        )
      end

      redirect_to importers_path
    end

    private

    def set_importer
      @importer = Importer.find(params[:importer_id])
    end
  end
end
