# frozen_string_literal: true
module HyraxHelper
  include ::BlacklightHelper
  include Hyrax::BlacklightOverride
  include Hyrax::HyraxHelperBehavior

  def child_crc_work_type_label(presenter)
    if presenter.crc_work_type.present?
      case presenter.crc_work_type[0]
      when 'experiment'
        'subject'
      when 'subject'
        'session'
      when 'session'
        'modality'
      else
        nil
      end
    else
      'experiment'
    end
  end

  def available_translations
    {
      'de' => 'Deutsch',
      'en' => 'English',
      'es' => 'Español',
      'fr' => 'Français',
      'it' => 'Italiano',
      'pt-BR' => 'Português do Brasil',
      'zh' => '中文'
    }.slice(RDMS::Application.config.i18n.available_locales )
  end

  def s3_file_download_url_for_file_set(file_set_id)
    file_set = FileSet.find(file_set_id)

    bucket = Aws::S3::Resource.new(region: ENV['S3_REGION']).bucket(file_set.parent_works.first.id)

    begin
      latest_version_uri = file_set.latest_content_version.uri
      file_key = "/#{file_set_id}/files/#{latest_version_uri.split("/")[-3]}/#{file_set.title.first}"
    rescue
      begin
        latest_version_uri = file_set.files[0]
        file_key = "/#{file_set_id}/files/#{latest_version_uri.split("/")[-1]}/#{file_set.title.first}"
      rescue
        return nil
      end
    end
    url_options = {
      expires_in: 60.minutes.seconds.to_i,
      response_content_disposition: "attachment; filename=\"#{file_key}\""
    }

    object = bucket.object(file_key)
    object.exists? ? object.presigned_url(:get, url_options).to_s : nil
  end
end
