class NestedSubjectInput < NestedAttributesInput

protected

  def build_components(attribute_name, value, index, options, parent=@builder.object_name)
    out = ''

    # Inherit required for fields validated in nested attributes
    required  = false
    if object.required?(:complex_subject) and index == 0
      required = true
    end

    # Add remove elemnt only if element repeats
    repeats = options.delete(:repeats)
    repeats = true if repeats.nil?

    parent_attribute = name_for(attribute_name, index, '', parent)[0..-5]

    # --- identifier
    field = :subject_identifier
    field_name = name_for(attribute_name, index, field, parent)
    field_id = id_for(attribute_name, index, field, parent)
    field_value = value.send(field).first

    out << "<div class='row'>"
    out << "  <div class='col-md-3'>"
    out << template.label_tag(field_name, I18n.t('rdms.fields.complex_subject_identifier'), required: required)
    out << '  </div>'

    out << "  <div class='col-md-9'>"
    out << @builder.text_field(field_name,
        options.merge(value: field_value, name: field_name, id: field_id, required: required, placeholder: "identifier"))
    out << '  </div>'
    out << '</div>' # row

    # --- subject_species
    field = :subject_species
    field_name = name_for(attribute_name, index, field, parent)
    field_id = id_for(attribute_name, index, field, parent)
    field_value = value.send(field).first
    role_options = SubjectSpeciesService.new.select_all_options

    out << "<div class='row'>"
    out << "  <div class='col-md-3'>"
    out << template.label_tag(field_name, I18n.t('rdms.fields.complex_subject_species'), required: required)
    out << '  </div>'

    out << "  <div class='col-md-9'>"
    out << template.select_tag(field_name,
                               template.options_for_select(role_options, field_value),
                               label: '', class: 'select form-control', prompt: 'choose species',
                               id: field_id, required: required)
    out << '  </div>'
    out << '</div>' # row

    # --- subject_type
    field = :subject_type
    field_name = name_for(attribute_name, index, field, parent)
    field_id = id_for(attribute_name, index, field, parent)
    field_value = value.send(field).first
    role_options = SubjectTypeService.new.select_all_options

    out << "<div class='row'>"
    out << "  <div class='col-md-3'>"
    out << template.label_tag(field_name, I18n.t('rdms.fields.complex_subject_type'), required: required)
    out << '  </div>'

    out << "  <div class='col-md-9'>"
    out << template.select_tag(field_name,
                               template.options_for_select(role_options, field_value),
                               label: '', class: 'select form-control', prompt: 'choose type',
                               id: field_id, required: required)
    out << '  </div>'
    out << '</div>' # row

    # --- subject_sex
    field = :subject_sex
    field_name = name_for(attribute_name, index, field, parent)
    field_id = id_for(attribute_name, index, field, parent)
    field_value = value.send(field).first
    role_options = SubjectSexService.new.select_all_options

    out << "<div class='row'>"
    out << "  <div class='col-md-3'>"
    out << template.label_tag(field_name, I18n.t('rdms.fields.complex_subject_sex'), required: required)
    out << '  </div>'

    out << "  <div class='col-md-9'>"
    out << template.select_tag(field_name,
                               template.options_for_select(role_options, field_value),
                               label: '', class: 'select form-control', prompt: 'choose sex',
                               id: field_id, required: required)
    out << '  </div>'
    out << '</div>' # row

    # --- age
    field = :subject_age
    field_name = name_for(attribute_name, index, field, parent)
    field_id = id_for(attribute_name, index, field, parent)
    field_value = value.send(field).first

    out << "<div class='row'>"
    out << "  <div class='col-md-3'>"
    out << template.label_tag(field_name, I18n.t('rdms.fields.complex_subject_age'), required: required)
    out << '  </div>'

    out << "  <div class='col-md-9'>"
    out << @builder.text_field(field_name,
        options.merge(value: field_value, name: field_name, id: field_id, required: required, placeholder: "age"))
    out << '  </div>'
    out << '</div>' # row

    if repeats == true
      field_label = 'Subject'
      out << "<div class='row'>"
      out << "  <div class='col-md-3'>"
      out << destroy_widget(attribute_name, index, field_label, parent)
      out << '  </div>'
      out << '</div>' # last row
    end

    out
  end
end
